@@ -238,12 +238,12 @@ def init_route(app, server, url_prefix):  # noqa: C901
         app.sample_view.start_auto_centring()
         return Response(status=200)
 
-    @bp.route("/centring/start3click", methods=["PUT"])
+    @bp.route("/centring/start_click_centring", methods=["PUT"])
     @server.require_control
     @server.restrict
-    def centre_3_click():
+    def centre_click():
         """
-        Start 3 click centring procedure.
+        Start Click centring procedure.
             :statuscode: 200: no error
             :statuscode: 409: error
         """
@@ -251,7 +251,10 @@ def init_route(app, server, url_prefix):  # noqa: C901
         try:
             data = app.sample_view.start_manual_centring()
         except Exception:
-            logging.getLogger("MX3.HWR").exception("Could not start 3 click centring")
+            msg = "Could not start %s click centring"
+            logging.getLogger("MX3.HWR").exception(
+                msg, HWR.beamline.config.click_centring_num_clicks
+            )
             resp = (
                 "Could not move motor",
                 409,
@@ -280,7 +283,7 @@ def init_route(app, server, url_prefix):  # noqa: C901
     @server.restrict
     def click():
         """
-        The 3-click method needs the input from the user, a running 3click centring
+        The click method needs the input from the user, a running click centring
         procedure must be set before
 
         :request Content-type: application/json, integer positions of the clicks,
